<?php

/**
 * Mino custom widget
 *
 * @package 	Mino
 * @since 		1.0.1
 * @version 	1.0.5
 */

/**
 * Custom Recent Post Widget
 *
 * 	Additional info about author post will be showed
 *
 * 	@since 1.0
 */
class Mino_Widget_Recent_Posts extends WP_Widget {

	/**
	 * 	Set recent post instance
	 */
	public function __construct() {
		$widget_ops = array(
			'classname' 	=> 'widget-recent',
			'description' 	=> __( "Your site&#8217;s most recent Posts.", 'mino' )
		);
		parent::__construct( 'recent-posts', __( 'Recent Posts', 'mino' ), $widget_ops );
		$this->alt_option_name = 'widget_recent_entries';
	}

	/**
	 * 	Outputs the content for the custom Recent Posts
	 *  @param  array $args     Argument for widgets
	 *  @param  array $instance Widget settings data
	 *  @return -
	 */
	public function widget( $args, $instance ) {

		if ( ! isset( $args['widget_id'] ) ) {
			$args['widget_id'] = $this->id;
		}

		$title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : __( 'Recent Posts', 'mino' );

		/** This filter is documented in wp-includes/widgets/class-wp-widget-pages.php */
		$title = apply_filters( 'widget_title', $title, $instance, $this->id_base );

		$number = ( ! empty( $instance['number'] ) ) ? absint( $instance['number'] ) : 5;
		if ( ! $number )
			$number = 5;

		$show_date 	 = isset( $instance['show_date'] ) ? $instance['show_date'] : false;
		$show_author = isset( $instance['show_author'] ) ? $instance['show_author'] : false;

		$r = new WP_Query( apply_filters( 'widget_posts_args', array(
			'posts_per_page'      => $number,
			'no_found_rows'       => true,
			'post_status'         => 'publish',
			'ignore_sticky_posts' => true
		) ) );

		if ( $r->have_posts() ) :

			echo $args['before_widget'];

			if ( $title ) {
				echo $args['before_title'] . $title . $args['after_title'];
			}

		?>

		<ul id="recent-post-list">
			<?php while ( $r->have_posts() ) : $r->the_post(); ?>
				<li>
					<a class="post-title" href="<?php the_permalink(); ?>">
						<?php get_the_title() ? the_title() : the_ID(); ?>
					</a>

					<p class="meta-entry">

						<?php if ( $show_date ) : ?>
							<span class="post-date"><?php echo get_the_date(); ?></span>
						<?php endif; ?>

						<?php if ( $show_author ) : ?>
							<span class="author"> <?php _e( 'by', 'mino' ); ?> <?php the_author_posts_link(); ?></span>
						<?php endif; ?>

					</p>
				</li>
			<?php endwhile; ?>
		</ul>

		<?php

			echo $args['after_widget'];

			/* Reset the global $the_post as this query will have stomped on it */
			wp_reset_postdata();

		endif;
	}

	/**
	 * 	Handles updating the settings for the current Recent Posts widget instance.
	 *
	 *  @param 	array $new_instance 	New settings for this instance as input by the user via WP_Widget::form().
	 *  @param 	array $old_instance 	Old settings for this instance.
	 *  @return array 					Updated settings to save.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance 				 = $old_instance;
		$instance['title'] 		 = sanitize_text_field( $new_instance['title'] );
		$instance['number'] 	 = (int) $new_instance['number'];
		$instance['show_date'] 	 = isset( $new_instance['show_date'] ) ? (bool) $new_instance['show_date'] : false;
		$instance['show_author'] = isset( $new_instance['show_author'] ) ? (bool) $new_instance['show_author'] : false;
		return $instance;
	}

	/**
	 * Outputs the settings form for the Recent Posts widget.
	 *
	 * @param 	array $instance 	Current settings.
	 */
	public function form( $instance ) {
		$title     	 = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
		$number    	 = isset( $instance['number'] ) ? absint( $instance['number'] ) : 5;
		$show_date 	 = isset( $instance['show_date'] ) ? (bool) $instance['show_date'] : false;
		$show_author = isset( $instance['show_author'] ) ? (bool) $instance['show_author'] : false;
?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>">
				<?php _e( 'Title:', 'mino' ); ?>
			</label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo $title; ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'number' ); ?>">
				<?php _e( 'Number of posts to show:', 'mino' ); ?>
			</label>
		<input class="tiny-text" id="<?php echo $this->get_field_id( 'number' ); ?>" name="<?php echo $this->get_field_name( 'number' ); ?>" type="number" step="1" min="1" value="<?php echo $number; ?>" size="3" /></p>

		<p><input class="checkbox" type="checkbox"<?php checked( $show_date ); ?> id="<?php echo $this->get_field_id( 'show_date' ); ?>" name="<?php echo $this->get_field_name( 'show_date' ); ?>" />
		<label for="<?php echo $this->get_field_id( 'show_date' ); ?>"><?php _e( 'Display post date?', 'mino' ); ?></label></p>

		<p><input class="checkbox" type="checkbox"<?php checked( $show_author ); ?> id="<?php echo $this->get_field_id( 'show_author' ); ?>" name="<?php echo $this->get_field_name( 'show_author' ); ?>" />
		<label for="<?php echo $this->get_field_id( 'show_author' ); ?>"><?php _e( 'Display author post?', 'mino' ); ?></label></p>
<?php
	}
}

/**
 * Register custom recent post widget
 *  @return -
 */
if ( ! function_exists( 'Mino_Register_Widget_Recent_Posts' ) ) {
	function Mino_Register_Widget_Recent_Posts() {
		// unregister_widget( 'WP_Widget_Recent_Posts' );
		register_widget( 'Mino_Widget_Recent_Posts' );
	}
}

/**
 * Woocommerce filter part
 */
if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {

	/**
	 * Price Filter Widget and related functions.
	 *
	 * Generates a range slider to filter products by price.
	 *
	 * @modified Tonjoo
	 * @category Widgets
	 * @package  Mino/inc
	 * @version  2.3.0
	 * @extends  WC_Widget_Price_Filter
	 */
	class Mino_Widget_Price_Filter extends WC_Widget_Price_Filter {

		/**
		 * Output widget.
		 *
		 * @see WP_Widget
		 *
		 * @param array $args
		 * @param array $instance
		 */
		public function widget( $args, $instance ) {

			global $wp, $wp_the_query;

			if ( ! is_post_type_archive( 'product' ) && ! is_tax( get_object_taxonomies( 'product' ) ) ) {
				return;
			}

			if ( ! $wp_the_query->post_count ) {
				return;
			}

			$min_price = isset( $_GET['min_price'] ) ? esc_attr( $_GET['min_price'] ) : '';
			$max_price = isset( $_GET['max_price'] ) ? esc_attr( $_GET['max_price'] ) : '';

			wp_enqueue_script( 'wc-price-slider' );

			// Remember current filters/search
			$fields = '';

			if ( get_search_query() ) {
				$fields .= '<input type="hidden" name="s" value="' . get_search_query() . '" />';
			}

			if ( ! empty( $_GET['post_type'] ) ) {
				$fields .= '<input type="hidden" name="post_type" value="' . esc_attr( $_GET['post_type'] ) . '" />';
			}

			if ( ! empty ( $_GET['product_cat'] ) ) {
				$fields .= '<input type="hidden" name="product_cat" value="' . esc_attr( $_GET['product_cat'] ) . '" />';
			}

			if ( ! empty( $_GET['product_tag'] ) ) {
				$fields .= '<input type="hidden" name="product_tag" value="' . esc_attr( $_GET['product_tag'] ) . '" />';
			}

			if ( ! empty( $_GET['orderby'] ) ) {
				$fields .= '<input type="hidden" name="orderby" value="' . esc_attr( $_GET['orderby'] ) . '" />';
			}

			if ( ! empty( $_GET['min_rating'] ) ) {
				$fields .= '<input type="hidden" name="min_rating" value="' . esc_attr( $_GET['min_rating'] ) . '" />';
			}

			if ( $_chosen_attributes = WC_Query::get_layered_nav_chosen_attributes() ) {
				foreach ( $_chosen_attributes as $attribute => $data ) {
					$taxonomy_filter = 'filter_' . str_replace( 'pa_', '', $attribute );

					$fields .= '<input type="hidden" name="' . esc_attr( $taxonomy_filter ) . '" value="' . esc_attr( implode( ',', $data['terms'] ) ) . '" />';

					if ( 'or' == $data['query_type'] ) {
						$fields .= '<input type="hidden" name="' . esc_attr( str_replace( 'pa_', 'query_type_', $attribute ) ) . '" value="or" />';
					}
				}
			}

			// Find min and max price in current result set
			$prices = $this->get_filtered_price();
			$min    = floor( $prices->min_price );
			$max    = ceil( $prices->max_price );

			if ( $min === $max ) {
				return;
			}

			$this->widget_start( $args, $instance );

			if ( '' === get_option( 'permalink_structure' ) ) {
				$form_action = remove_query_arg( array( 'page', 'paged' ), add_query_arg( $wp->query_string, '', home_url( $wp->request ) ) );
			} else {
				$form_action = preg_replace( '%\/page/[0-9]+%', '', home_url( trailingslashit( $wp->request ) ) );
			}

			/**
			 * Adjust max if the store taxes are not displayed how they are stored.
			 * Min is left alone because the product may not be taxable.
			 * Kicks in when prices excluding tax are displayed including tax.
			 */
			if ( wc_tax_enabled() && 'incl' === get_option( 'woocommerce_tax_display_shop' ) && ! wc_prices_include_tax() ) {
				$tax_classes = array_merge( array( '' ), WC_Tax::get_tax_classes() );
				$class_max   = $max;

				foreach ( $tax_classes as $tax_class ) {
					if ( $tax_rates = WC_Tax::get_rates( $tax_class ) ) {
						$class_max = $max + WC_Tax::get_tax_total( WC_Tax::calc_exclusive_tax( $max, $tax_rates ) );
					}
				}

				$max = $class_max;
			}

			echo '<form method="get" action="' . esc_url( $form_action ) . '">
				<div class="price_slider_wrapper">
					<div class="price_slider" style="display:none;"></div>
					<div class="price_slider_amount">
						<input type="text" id="min_price" name="min_price" value="' . esc_attr( $min_price ) . '" data-min="' . esc_attr( apply_filters( 'woocommerce_price_filter_widget_min_amount', $min ) ) . '" placeholder="' . esc_attr__( 'Min price', 'mino' ) . '" />
						<input type="text" id="max_price" name="max_price" value="' . esc_attr( $max_price ) . '" data-max="' . esc_attr( apply_filters( 'woocommerce_price_filter_widget_max_amount', $max ) ) . '" placeholder="' . esc_attr__( 'Max price', 'mino' ) . '" />
						<button type="submit" class="button">' . __( 'Filter', 'mino' ) . '</button>
						<div class="price_label" style="display:none;">
							' . __( 'Price:', 'mino' ) . ' <span class="from"></span> &mdash; <span class="to"></span>
						</div>
						' . $fields . '
						<div class="clear"></div>
					</div>
				</div>
			</form>';

			$this->widget_end( $args );
		}
	}

	/**
	 * 	Register custom recent post widget
	 *  @return -
	 */
	if ( ! function_exists( 'Mino_Register_Widget_Price_Filter' ) ) {
		function Mino_Register_Widget_Price_Filter() {
			register_widget( 'Mino_Widget_Price_Filter' );
		}
	}
	add_action( 'widgets_init', 'Mino_Register_Widget_Price_Filter' );

	class Mino_Widget_Layered_Nav extends WC_Widget_Layered_Nav {

		/**
		 * Output widget.
		 *
		 * @see WP_Widget
		 *
		 * @param array $args
		 * @param array $instance
		 */
		public function widget( $args, $instance ) {
			global $_chosen_attributes;

			if ( ! is_post_type_archive( 'product' ) && ! is_tax( get_object_taxonomies( 'product' ) ) ) {
				return;
			}

			$current_term = is_tax() ? get_queried_object()->term_id : '';
			$current_tax  = is_tax() ? get_queried_object()->taxonomy : '';
			$taxonomy     = isset( $instance['attribute'] ) ? wc_attribute_taxonomy_name( $instance['attribute'] ) : $this->settings['attribute']['std'];
			$query_type   = isset( $instance['query_type'] ) ? $instance['query_type'] : $this->settings['query_type']['std'];
			$display_type = isset( $instance['display_type'] ) ? $instance['display_type'] : $this->settings['display_type']['std'];

			if ( ! taxonomy_exists( $taxonomy ) ) {
				return;
			}

			$get_terms_args = array( 'hide_empty' => '1' );

			$orderby = wc_attribute_orderby( $taxonomy );

			switch ( $orderby ) {
				case 'name' :
					$get_terms_args['orderby']    = 'name';
					$get_terms_args['menu_order'] = false;
				break;
				case 'id' :
					$get_terms_args['orderby']    = 'id';
					$get_terms_args['order']      = 'ASC';
					$get_terms_args['menu_order'] = false;
				break;
				case 'menu_order' :
					$get_terms_args['menu_order'] = 'ASC';
				break;
			}

			$terms = get_terms( $taxonomy, $get_terms_args );

			if ( 0 < count( $terms ) ) {

				ob_start();

				$found = false;

				$this->widget_start( $args, $instance );

				// Force found when option is selected - do not force found on taxonomy attributes
				if ( ! is_tax() && is_array( $_chosen_attributes ) && array_key_exists( $taxonomy, $_chosen_attributes ) ) {
					$found = true;
				}

				if ( 'dropdown' == $display_type ) {

					// skip when viewing the taxonomy
					if ( $current_tax && $taxonomy == $current_tax ) {

						$found = false;

					} else {

						$taxonomy_filter = str_replace( 'pa_', '', $taxonomy );

						$found = false;

						echo '<select class="dropdown_layered_nav_' . $taxonomy_filter . '">';

						echo '<option value="">' . sprintf( __( 'Any %s', 'mino' ), wc_attribute_label( $taxonomy ) ) . '</option>';

						foreach ( $terms as $term ) {

							// If on a term page, skip that term in widget list
							if ( $term->term_id == $current_term ) {
								continue;
							}

							// Get count based on current view
							$_products_in_term = wc_get_term_product_ids( $term->term_id, $taxonomy );
							$option_is_set     = ( isset( $_chosen_attributes[ $taxonomy ] ) && in_array( $term->term_id, $_chosen_attributes[ $taxonomy ]['terms'] ) );

							// If this is an AND query, only show options with count > 0
							if ( 'and' == $query_type ) {

								$count = sizeof( array_intersect( $_products_in_term, WC()->query->filtered_product_ids ) );

								if ( 0 < $count ) {
									$found = true;
								}

								if ( 0 == $count && ! $option_is_set ) {
									continue;
								}

							// If this is an OR query, show all options so search can be expanded
							} else {

								$count = sizeof( array_intersect( $_products_in_term, WC()->query->unfiltered_product_ids ) );

								if ( 0 < $count ) {
									$found = true;
								}

							}

							echo '<option value="' . esc_attr( $term->term_id ) . '" ' . selected( isset( $_GET[ 'filter_' . $taxonomy_filter ] ) ? esc_attr( $_GET[ 'filter_' . $taxonomy_filter ] ) : '' , $term->term_id, false ) . '>' . esc_html( $term->name ) . '</option>';
						}

						echo '</select>';

						wc_enqueue_js( "
							jQuery( '.dropdown_layered_nav_$taxonomy_filter' ).change( function() {
								var term_id = parseInt( jQuery( this ).val(), 10 );
								location.href = '" . preg_replace( '%\/page\/[0-9]+%', '', str_replace( array( '&amp;', '%2C' ), array( '&', ',' ), esc_js( add_query_arg( 'filtering', '1', remove_query_arg( array( 'page', 'filter_' . $taxonomy_filter ) ) ) ) ) ) . "&filter_$taxonomy_filter=' + ( isNaN( term_id ) ? '' : term_id );
							});
						" );

					}

				} else {

					// List display
					echo '<ul>';

					foreach ( $terms as $term ) {

						// Get count based on current view - uses transients
						$_products_in_term = wc_get_term_product_ids( $term->term_id, $taxonomy );
						$option_is_set     = ( isset( $_chosen_attributes[ $taxonomy ] ) && in_array( $term->term_id, $_chosen_attributes[ $taxonomy ]['terms'] ) );

						// skip the term for the current archive
						if ( $current_term == $term->term_id ) {
							continue;
						}

						// If this is an AND query, only show options with count > 0
						if ( 'and' == $query_type ) {

							$count = sizeof( array_intersect( $_products_in_term, WC()->query->filtered_product_ids ) );

							if ( 0 < $count && $current_term !== $term->term_id ) {
								$found = true;
							}

							if ( 0 == $count && ! $option_is_set ) {
								continue;
							}

						// If this is an OR query, show all options so search can be expanded
						} else {

							$count = sizeof( array_intersect( $_products_in_term, WC()->query->unfiltered_product_ids ) );

							if ( 0 < $count ) {
								$found = true;
							}
						}

						$arg = 'filter_' . sanitize_title( $instance['attribute'] );

						$current_filter = ( isset( $_GET[ $arg ] ) ) ? explode( ',', $_GET[ $arg ] ) : array();

						if ( ! is_array( $current_filter ) ) {
							$current_filter = array();
						}

						$current_filter = array_map( 'esc_attr', $current_filter );

						if ( ! in_array( $term->term_id, $current_filter ) ) {
							$current_filter[] = $term->term_id;
						}

						// Base Link decided by current page
						if ( defined( 'SHOP_IS_ON_FRONT' ) ) {
							$link = esc_url( home_url() );
						} elseif ( is_post_type_archive( 'product' ) || is_page( wc_get_page_id('shop') ) ) {
							$link = get_post_type_archive_link( 'product' );
						} else {
							$current_term = get_queried_object();
							$link = get_term_link( $current_term->term_id, $current_term->taxonomy );
						}

						// All current filters
						if ( $_chosen_attributes ) {
							foreach ( $_chosen_attributes as $name => $data ) {
								if ( $name !== $taxonomy ) {

									// Exclude query arg for current term archive term
									while ( in_array( $current_term, $data['terms'] ) ) {
										$key = array_search( $current_term, $data );
										unset( $data['terms'][$key] );
									}

									// Remove pa_ and sanitize
									$filter_name = sanitize_title( str_replace( 'pa_', '', $name ) );

									if ( ! empty( $data['terms'] ) ) {
										$link = add_query_arg( 'filter_' . $filter_name, implode( ',', $data['terms'] ), $link );
									}

									if ( 'or' == $data['query_type'] ) {
										$link = add_query_arg( 'query_type_' . $filter_name, 'or', $link );
									}
								}
							}
						}

						// Min/Max
						if ( isset( $_GET['min_price'] ) ) {
							$link = add_query_arg( 'min_price', sanitize_text_field( $_GET['min_price'] ), $link );
						}

						if ( isset( $_GET['max_price'] ) ) {
							$link = add_query_arg( 'max_price', sanitize_text_field( $_GET['max_price'] ), $link );
						}

						// Orderby
						if ( isset( $_GET['orderby'] ) ) {
							$link = add_query_arg( 'orderby', sanitize_text_field( $_GET['orderby'] ), $link );
						}

						// Current Filter = this widget
						if ( isset( $_chosen_attributes[ $taxonomy ] ) && is_array( $_chosen_attributes[ $taxonomy ]['terms'] ) && in_array( $term->term_id, $_chosen_attributes[ $taxonomy ]['terms'] ) ) {

							$class = 'class="chosen"';

							// Remove this term is $current_filter has more than 1 term filtered
							if ( sizeof( $current_filter ) > 1 ) {
								$current_filter_without_this = array_diff( $current_filter, array( $term->term_id ) );
								$link = add_query_arg( $arg, implode( ',', $current_filter_without_this ), $link );
							}

						} else {

							$class = '';
							$link = add_query_arg( $arg, implode( ',', $current_filter ), $link );

						}

						// Search Arg
						if ( get_search_query() ) {
							$link = add_query_arg( 's', get_search_query(), $link );
						}

						// Post Type Arg
						if ( isset( $_GET['post_type'] ) ) {
							$link = add_query_arg( 'post_type', sanitize_text_field( $_GET['post_type'] ), $link );
						}

						// Query type Arg
						if ( $query_type == 'or' && ! ( sizeof( $current_filter ) == 1 && isset( $_chosen_attributes[ $taxonomy ]['terms'] ) && is_array( $_chosen_attributes[ $taxonomy ]['terms'] ) && in_array( $term->term_id, $_chosen_attributes[ $taxonomy ]['terms'] ) ) ) {
							$link = add_query_arg( 'query_type_' . sanitize_title( $instance['attribute'] ), 'or', $link );
						}

						echo '<li ' . $class . '>';

						echo ( $count > 0 || $option_is_set ) ? '<a href="' . esc_url( apply_filters( 'woocommerce_layered_nav_link', $link ) ) . '">' : '<span>';

						echo $term->name;

						echo ' <span class="count">' . $count . '</span>';

						echo ( $count > 0 || $option_is_set ) ? '</a>' : '</span>';

						echo '</li>';

					}

					echo '</ul>';

				} // End display type conditional

				$this->widget_end( $args );

				if ( ! $found ) {
					ob_end_clean();
				} else {
					echo ob_get_clean();
				}
			}
		}
	}

	/**
	 * 	Register custom recent post widget
	 *  @return -
	 */
	if ( ! function_exists( 'Mino_Register_Widget_Layered_Nav' ) ) {
		function Mino_Register_Widget_Layered_Nav() {
			register_widget( 'Mino_Widget_Layered_Nav' );
		}
	}
	add_action( 'widgets_init', 'Mino_Register_Widget_Layered_Nav' );

	class Mino_Widget_Recent_Reviews extends WC_Widget_Recent_Reviews {

		/**
		 * Output widget.
		 *
		 * @see WP_Widget
		 *
		 * @param array $args
		 * @param array $instance
		 */
		public function widget( $args, $instance ) {
			global $comments, $comment;

			if ( $this->get_cached_widget( $args ) ) {
				return;
			}

			ob_start();

			$number   = ! empty( $instance['number'] ) ? absint( $instance['number'] ) : $this->settings['number']['std'];
			$comments = get_comments( array( 'number' => $number, 'status' => 'approve', 'post_status' => 'publish', 'post_type' => 'product' ) );

			if ( $comments ) {
				$this->widget_start( $args, $instance );

				echo '<ul class="product_list_widget">';

				foreach ( (array) $comments as $comment ) {

					$_product = wc_get_product( $comment->comment_post_ID );

					$rating = intval( get_comment_meta( $comment->comment_ID, 'rating', true ) );

					$rating_html = $_product->get_rating_html( $rating );

					echo '<li class="col-md-12 col-xs-12"><div class="row">';
					echo '<div class="col-md-3 col-xs-12">';
					echo $_product->get_image();
					echo '</div>';
					echo '<div class="col-md-9 col-xs-12">';
					echo '<a href="' . esc_url( get_comment_link( $comment->comment_ID ) ) . '">';
					echo '<h5 class="product-title">' . $_product->get_title() . '</h5>' . '</a>';
					echo $rating_html;

					printf( '<span class="reviewer">' . _x( 'by %1$s', 'by comment author', 'mino' ) . '</span>', get_comment_author() );

					echo '</div></div></li>';
				}

				echo '</ul>';

				$this->widget_end( $args );
			}

			$content = ob_get_clean();

			echo $content;

			$this->cache_widget( $args, $content );
		}
	}

	/**
	 * 	Register custom recent product reviews
	 *  @return -
	 */
	if ( ! function_exists( 'Mino_Register_WC_Widget_Recent_Reviews' ) ) {
		function Mino_Register_WC_Widget_Recent_Reviews() {
			register_widget( 'Mino_Widget_Recent_Reviews' );
		}
	}
	add_action( 'widgets_init', 'Mino_Register_WC_Widget_Recent_Reviews' );

}